pub enum Error {
ClipboardUnavailable,
ClipboardOccupied,
ContentNotAvailable,
ConversionFailure,
Unknown {
description: Arc<String>,
},
}Expand description
A clipboard error.
Variants
The clipboard in the current environment is either not present or could not be accessed.
ClipboardOccupied
The native clipboard is not accessible due to being held by another party.
ContentNotAvailable
The clipboard contents were not available in the requested format. This could either be due to the clipboard being empty or the clipboard contents having an incompatible format to the requested one
ConversionFailure
The image or the text that was about the be transferred to/from the clipboard could not be converted to the appropriate format.
Unknown
Any error that doesn’t fit the other error types.